# Driftage
![](https://github.com/dmvieira/driftage/blob/master/doc/images/driftage_only_logo.png)

[![Build Status](https://travis-ci.com/dmvieira/driftage.svg?branch=master)](https://travis-ci.com/dmvieira/driftage)
[![Coverage Status](https://coveralls.io/repos/github/dmvieira/driftage/badge.svg?branch=master)](https://coveralls.io/github/dmvieira/driftage?branch=master)

Multi-agent Drift Detection Framework

## Install

Using Python 3.7+

```sh
pip install driftage
```

## Usage

Check [Documentation](https://driftage.readthedocs.io) for more information.

## Contribute

For development and contributing, please follow [Contributing Guide](https://github.com/dmvieira/driftage/blob/master/CONTRIBUTING.md) and **ALWAYS** respect the [Code of Conduct](https://github.com/dmvieira/driftage/blob/master/CODE_OF_CONDUCT.md).
